==> krita-2.99.89.tar.xz: krita-2.99.89/libs/image/kis_change_profile_visitor.h <==
/*
 *  Copyright (c) 2006 Boudewijn Rempt <boud@valdyas.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#ifndef KIS_CHANGE_PROFILE_VISITOR_H_
#define KIS_CHANGE_PROFILE_VISITOR_H_

#include "KoColorSpace.h"

#include "kis_types.h"
#include "kis_node_visitor.h"
#include "kis_paint_layer.h"
#include "kis_adjustment_layer.h"
#include "generator/kis_generator_layer.h"
#include "kis_group_layer.h"

class KisExternalLayer;
// #include "kis_external_layer_iface.h"

/**
 * The Change Profile visitor walks over all layers and if the current
 * layer has the specified colorspace AND the specified old profile, sets
 * the colorspace to the same colorspace with the NEW profile, without doing
 * conversions. This is essential if you have loaded an image that didn't
 * have an embedded profile to which you want to attach the right profile.
 */
class KisChangeProfileVisitor : public KisNodeVisitor
{
public:

    using KisNodeVisitor::visit;

    KisChangeProfileVisitor(const KoColorSpace * oldColorSpace,
                            const KoColorSpace *dstColorSpace)
            : KisNodeVisitor()
            , m_oldColorSpace(oldColorSpace)
            , m_dstColorSpace(dstColorSpace) {
    }

    ~KisChangeProfileVisitor() {
    }

    bool visit(KisExternalLayer *) {
        return true;
    }

    bool visit(KisGroupLayer * layer) {
        // Clear the projection, we will have to re-render everything.
        layer->resetCache();

        KisLayerSP child = dynamic_cast<KisLayer*>(layer->firstChild().data());
        while (child) {
            child->accept(*this);
            child = dynamic_cast<KisLayer*>(child->nextSibling().data());
        }
        return true;
    }


    bool visit(KisPaintLayer *layer) {
        return updatePaintDevice(layer);
    }

    bool visit(KisGeneratorLayer *layer) {
        return updatePaintDevice(layer);
    }

    bool visit(KisAdjustmentLayer * layer) {
        layer->resetCache();
        return true;
    }

    bool visit(KisNode*) {
        return true;
    }
    bool visit(KisCloneLayer*) {
        return true;
    }
    bool visit(KisFilterMask*) {
        return true;
    }
    bool visit(KisTransformMask*) {
        return true;
    }
    bool visit(KisTransparencyMask*) {
        return true;
    }
    bool visit(KisSelectionMask*) {
        return true;
    }

private:

    bool updatePaintDevice(KisLayer *layer) {
        if (!layer) return false;
        if (!layer->paintDevice()) return false;
        if (!layer->paintDevice()->colorSpace()) return false;

        const KoColorSpace *cs = layer->paintDevice()->colorSpace();

        if (cs->colorModelId() == m_oldColorSpace->colorModelId()) {
            layer->paintDevice()->setProfile(m_dstColorSpace->profile());
            if (layer->projection() != layer->paintDevice()) {
                layer->projection()->setProfile(m_dstColorSpace->profile());
            }
        }


        return true;
    }

    const KoColorSpace *m_oldColorSpace;
    const KoColorSpace *m_dstColorSpace;
};

#endif // KIS_CHANGE_PROFILE_VISITOR_H_

==> krita_4.1.7+dfsg.orig.tar.xz: krita-4.1.7.101/libs/image/kis_change_profile_visitor.h <==
/*
 *  Copyright (c) 2006 Boudewijn Rempt <boud@valdyas.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#ifndef KIS_CHANGE_PROFILE_VISITOR_H_
#define KIS_CHANGE_PROFILE_VISITOR_H_

#include "KoColorSpace.h"

#include "kis_types.h"
#include "kis_node_visitor.h"
#include "kis_paint_layer.h"
#include "lazybrush/kis_colorize_mask.h"
#include "kis_adjustment_layer.h"
#include "generator/kis_generator_layer.h"
#include "kis_group_layer.h"

class KisExternalLayer;
// #include "kis_external_layer_iface.h"

#include <kritaimage_export.h>

/**
 * The Change Profile visitor walks over all layers and if the current
 * layer has the specified colorspace AND the specified old profile, sets
 * the colorspace to the same colorspace with the NEW profile, without doing
 * conversions. This is essential if you have loaded an image that didn't
 * have an embedded profile to which you want to attach the right profile.
 */
class KRITAIMAGE_EXPORT KisChangeProfileVisitor : public KisNodeVisitor
{
public:

    using KisNodeVisitor::visit;

    KisChangeProfileVisitor(const KoColorSpace * oldColorSpace,
                            const KoColorSpace *dstColorSpace)
            : KisNodeVisitor()
            , m_oldColorSpace(oldColorSpace)
            , m_dstColorSpace(dstColorSpace) {
    }

    ~KisChangeProfileVisitor() override {
    }

    bool visit(KisExternalLayer *) override {
        return true;
    }

    bool visit(KisGroupLayer * layer) override {
        // Clear the projection, we will have to re-render everything.
        layer->resetCache();

        KisLayerSP child = dynamic_cast<KisLayer*>(layer->firstChild().data());
        while (child) {
            child->accept(*this);
            child = dynamic_cast<KisLayer*>(child->nextSibling().data());
        }
        return true;
    }


    bool visit(KisPaintLayer *layer) override {
        return updatePaintDevice(layer);
    }

    bool visit(KisGeneratorLayer *layer) override {
        return updatePaintDevice(layer);
    }

    bool visit(KisAdjustmentLayer * layer) override {
        layer->resetCache();
        return true;
    }

    bool visit(KisNode*) override {
        return true;
    }
    bool visit(KisCloneLayer*) override {
        return true;
    }
    bool visit(KisFilterMask*) override {
        return true;
    }
    bool visit(KisTransformMask*) override {
        return true;
    }
    bool visit(KisTransparencyMask*) override {
        return true;
    }
    bool visit(KisSelectionMask*) override {
        return true;
    }

    bool visit(KisColorizeMask *mask) override {
        if (mask->colorSpace()->colorModelId() == m_oldColorSpace->colorModelId()) {
            mask->setProfile(m_dstColorSpace->profile());
        }
        return true;
    }

private:

    bool updatePaintDevice(KisLayer *layer) {
        if (!layer) return false;
        if (!layer->paintDevice()) return false;
        if (!layer->paintDevice()->colorSpace()) return false;

        const KoColorSpace *cs = layer->paintDevice()->colorSpace();

        if (cs->colorModelId() == m_oldColorSpace->colorModelId()) {
            layer->paintDevice()->setProfile(m_dstColorSpace->profile());
            if (layer->projection() != layer->paintDevice()) {
                layer->projection()->setProfile(m_dstColorSpace->profile());
            }
        }


        return true;
    }

    const KoColorSpace *m_oldColorSpace;
    const KoColorSpace *m_dstColorSpace;
};

#endif // KIS_CHANGE_PROFILE_VISITOR_H_
